@@ -4,10 +4,15 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from sys import stderr
 from time import sleep as time_sleep
 from typing import Dict, List, Optional
 
-import vlc
+try:
+    import vlc  # noqa: F401
+except OSError:
+    print("vlc not found.", file=stderr)
+    exit(1)
 
 from exclock.util import get_real_sound_filename, get_time_delta_from_str, notify_all
 
@@ -82,12 +87,12 @@ class ClockTimer:
 
         secs = list(sounds.keys())
         for i, (sec, sound) in enumerate(sounds.items()):
-            spend_time = secs[i] - (0 if i == 0 else secs[i - 1])
+            spend_sec = secs[i] - (0 if i == 0 else secs[i - 1])
             message = inner_str(sound.message, {"count": count})
             notify_all(
                 title=self.title,
                 message=message,
-                spend_time=spend_time,
+                spend_sec=spend_sec,
                 is_first=sec == 0 and count == 1)
 
             ps.append(sound.run())
