@@ -60,7 +60,7 @@ def main(opt, args) -> None:
             exit(1)
 
         message = f"Specified time is passed(sec={spend_sec})."
-        notify_all(title="Exclock", message=message, spend_time=spend_sec, is_first=False)
+        notify_all(title="⏰ Exclock ⏰", message=message, spend_sec=spend_sec, is_first=False)
 
         p = vlc.MediaPlayer(ring_sound_filename)
         p.play()
