@@ -2,9 +2,11 @@
 # -*- coding: utf-8 -*-
 
 import os
+import shutil
 from os.path import basename as _path_basename
 from pathlib import Path
 from shlex import quote
+from sys import stdout
 from time import sleep as time_sleep
 from typing import List, Tuple
 
@@ -18,6 +20,10 @@ CLOCK_DIR_IN_SYS = Path(os.getenv('EXCLOCK_CLOCK_DIR', str(ASSET_DIR_IN_SYS / "c
 SOUND_DIR_IN_SYS = Path(os.getenv('EXCLOCK_SOUND_DIR', str(ASSET_DIR_IN_SYS / "sound"))).absolute()
 
 
+def executable(cmd: str) -> bool:
+    return bool(shutil.which(cmd))
+
+
 def get_clock_basenames() -> List[str]:
     clock_paths = set(CLOCK_DIR_IN_SYS.glob("**/*"))
     clock_paths |= set(CLOCK_DIR_IN_PROG.glob("**/*"))
@@ -144,23 +150,35 @@ def get_real_sound_filename(path_: str) -> str:
     return str(SOUND_DIR_IN_PROG / path_name)
 
 
-def notify(title: str, message: str) -> None:
-    message = quote(title + "\n" + message)
-    os.system(f'(xmessage -nearmouse -timeout 20 -buttons Close {message}) &')
+def notify(title: str, message: str, cmd_io=None) -> None:
+    if executable('terminal-notifier'):
+        title = quote(title)
+        message = quote(message)
+        cmd = f'(terminal-notifier -title {title} -message {message}) &'
+    else:  # use xmessage
+        message = quote(title + "\n" + message)
+        cmd = f'(xmessage -nearmouse -timeout 20 -buttons Close {message}) &'
+
+    if cmd_io is None:
+        os.system(cmd)
+    else:
+        print(cmd, file=cmd_io)
 
 
 def notify_all(
     title: str,
     message: str,
-    spend_time: int,
+    spend_sec: int,
     is_first: bool,
+    out_io=stdout,
+    cmd_io=None,
 ) -> None:
-    tqdm_f = (lambda i: i) if spend_time == 0 else lambda i: tqdm(
+    tqdm_f = (lambda i: i) if spend_sec == 0 else lambda i: tqdm(
         i, bar_format="{l_bar}{bar}| {n_fmt}/{total_fmt} ")
-    for _ in tqdm_f(range(spend_time)):
+    for _ in tqdm_f(range(spend_sec)):
         time_sleep(1)
 
     if not is_first:
-        notify(title=title, message=message)
+        notify(title=title, message=message, cmd_io=cmd_io)
 
-    print(message)
+    print(message, file=out_io)
